@@ -1,8 +1,8 @@
 /**************************************************************************************************
-	$Header: /pub/cvsroot/mydns/src/util/check.c,v 1.29 2004/02/27 03:26:42 bboy Exp $
+	$Header: /pub/cvsroot/mydns/src/util/check.c,v 1.32 2005/01/13 19:54:46 bboy Exp $
 	check.c: Check for problems with the data in the database.
 
-	Copyright (C) 2002-2003  Don Moore <bboy@bboy.net>
+	Copyright (C) 2002-2005  Don Moore <bboy@bboy.net>
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -458,8 +458,17 @@ check_rr(void)
 		case DNS_QTYPE_A:											/* Data: IPv4 address */
 			{
 				struct in_addr addr;
-				if (inet_pton(AF_INET, data, (void *)&addr) <= 0)
-					rrproblem(_("IPv4 address in `data' is invalid"));
+#if ALIAS_ENABLED
+				if (rr->alias == 1)
+					check_rr_cname();
+				else
+				{
+#endif /* ALIAS_ENABLED */
+					if (inet_pton(AF_INET, data, (void *)&addr) <= 0)
+						rrproblem(_("IPv4 address in `data' is invalid"));
+#if ALIAS_ENABLED
+				}
+#endif /* ALIAS_ENABLED */
 			}
 			break;
 
